import {
  View,
  ActivityIndicator,
  StyleProp,
  Text,
  StyleSheet,
} from 'react-native';
import {ViewStyle} from 'react-native';
import Table, {Line} from './Table';
import Status from '../../utils/Status';

interface BusListProps {
  buses: Line[];
  status: Status;
  style?: StyleProp<ViewStyle>;
}

const ERROR_MESSAGE = 'Ha ocurrido un error';
const EMPTY_MESSAGE = 'No buses available';

const BusList = ({buses, status, style}: BusListProps) => {
  return (
    <View style={style}>
      {status === Status.LOADING && <ActivityIndicator testID="LOADING" />}
      {status === Status.ERROR && (
        <Text style={styles.text}>{ERROR_MESSAGE}</Text>
      )}
      {status === Status.SUCCESS && buses.length === 0 ? (
        <Text style={styles.text}>{EMPTY_MESSAGE}</Text>
      ) : (
        <Table data={buses} />
      )}
    </View>
  );
};

const styles = StyleSheet.create({
  text: {
    textAlign: 'center',
  },
});

export default BusList;
